==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The configuration settings of the HTTP requests for authentication and authorization requests made against ContainerApp Service Authentication/Authorization.
 * @property forwardProxy The configuration settings of a forward proxy used to make the requests.
 * @property requireHttps <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
 * @property routes The configuration settings of the paths HTTP requests.
 */
public data class HttpSettingsArgs(
    public val forwardProxy: Output<ForwardProxyArgs>? = null,
    public val requireHttps: Output<Boolean>? = null,
    public val routes: Output<HttpSettingsRoutesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpSettingsArgs =
        com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder()
            .forwardProxy(forwardProxy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .requireHttps(requireHttps?.applyValue({ args0 -> args0 }))
            .routes(routes?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [HttpSettingsArgs].
 */
@PulumiTagMarker
public class HttpSettingsArgsBuilder internal constructor() {
    private var forwardProxy: Output<ForwardProxyArgs>? = null

    private var requireHttps: Output<Boolean>? = null

    private var routes: Output<HttpSettingsRoutesArgs>? = null

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("bltpgeiwekdujuct")
    public suspend fun forwardProxy(`value`: Output<ForwardProxyArgs>) {
        this.forwardProxy = value
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("pevnkxcccvamdvek")
    public suspend fun requireHttps(`value`: Output<Boolean>) {
        this.requireHttps = value
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("ofahbfwakavoeanf")
    public suspend fun routes(`value`: Output<HttpSettingsRoutesArgs>) {
        this.routes = value
    }

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("jarfrrspinnrhxvh")
    public suspend fun forwardProxy(`value`: ForwardProxyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forwardProxy = mapped
    }

    /**
     * @param argument The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("bpjpprigqmfswtqm")
    public suspend fun forwardProxy(argument: suspend ForwardProxyArgsBuilder.() -> Unit) {
        val toBeMapped = ForwardProxyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.forwardProxy = mapped
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("puuwillxagnqbskv")
    public suspend fun requireHttps(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requireHttps = mapped
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("yktqnnsjritxvfsq")
    public suspend fun routes(`value`: HttpSettingsRoutesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    /**
     * @param argument The configuration settings of the paths HTTP requests.
     */
    @JvmName("qxmscnqabmmvutxg")
    public suspend fun routes(argument: suspend HttpSettingsRoutesArgsBuilder.() -> Unit) {
        val toBeMapped = HttpSettingsRoutesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    internal fun build(): HttpSettingsArgs = HttpSettingsArgs(
        forwardProxy = forwardProxy,
        requireHttps = requireHttps,
        routes = routes,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The configuration settings of the HTTP requests for authentication and authorization requests made against ContainerApp Service Authentication/Authorization.
 * @property forwardProxy The configuration settings of a forward proxy used to make the requests.
 * @property requireHttps <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
 * @property routes The configuration settings of the paths HTTP requests.
 */
public data class HttpSettingsArgs(
    public val forwardProxy: Output<ForwardProxyArgs>? = null,
    public val requireHttps: Output<Boolean>? = null,
    public val routes: Output<HttpSettingsRoutesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpSettingsArgs =
        com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder()
            .forwardProxy(forwardProxy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .requireHttps(requireHttps?.applyValue({ args0 -> args0 }))
            .routes(routes?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [HttpSettingsArgs].
 */
@PulumiTagMarker
public class HttpSettingsArgsBuilder internal constructor() {
    private var forwardProxy: Output<ForwardProxyArgs>? = null

    private var requireHttps: Output<Boolean>? = null

    private var routes: Output<HttpSettingsRoutesArgs>? = null

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("rrjbiincuejtoxyy")
    public suspend fun forwardProxy(`value`: Output<ForwardProxyArgs>) {
        this.forwardProxy = value
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("fycsehuhajjlwcro")
    public suspend fun requireHttps(`value`: Output<Boolean>) {
        this.requireHttps = value
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("ntyhlrfmimnyivrl")
    public suspend fun routes(`value`: Output<HttpSettingsRoutesArgs>) {
        this.routes = value
    }

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("tbpxcrhhgypdkhkf")
    public suspend fun forwardProxy(`value`: ForwardProxyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forwardProxy = mapped
    }

    /**
     * @param argument The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("xxecfjpsiopibvup")
    public suspend fun forwardProxy(argument: suspend ForwardProxyArgsBuilder.() -> Unit) {
        val toBeMapped = ForwardProxyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.forwardProxy = mapped
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("wyegrloekrnfbghb")
    public suspend fun requireHttps(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requireHttps = mapped
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("aqkhotttwyatyiex")
    public suspend fun routes(`value`: HttpSettingsRoutesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    /**
     * @param argument The configuration settings of the paths HTTP requests.
     */
    @JvmName("wgdtjrdfpussaxcn")
    public suspend fun routes(argument: suspend HttpSettingsRoutesArgsBuilder.() -> Unit) {
        val toBeMapped = HttpSettingsRoutesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    internal fun build(): HttpSettingsArgs = HttpSettingsArgs(
        forwardProxy = forwardProxy,
        requireHttps = requireHttps,
        routes = routes,
    )
}
